@@ -1,3 +1,10 @@
+"""
+$description Live TV channels and video on-demand service from RTVE, a Spanish public, state-owned broadcaster.
+$url rtve.es
+$type live, vod
+$region Spain
+"""
+
 import base64
 import logging
 import re
