@@ -1,3 +1,10 @@
+"""
+$description Global live-streaming and video hosting social platform owned by Amazon.
+$url twitch.tv
+$type live, vod
+$notes :ref:`Low latency streaming <cli/plugins/twitch:Low latency streaming>` is supported
+"""
+
 import json
 import logging
 import re
@@ -464,7 +471,7 @@ class TwitchAPI:
         |
         (?P<channel>[^/?]+)
         (?:
-            /video/(?P<video_id>\d+)
+            /v(?:ideo)?/(?P<video_id>\d+)
             |
             /clip/(?P<clip_name>[^/?]+)
         )?
