@@ -1,4 +1,6 @@
+import os
 from pathlib import Path
+from unittest.mock import patch
 
 import pytest
 
@@ -64,3 +66,17 @@ def test_replace_path():
     path = Path("foo", ".", "bar", "..", "baz")
     expected = Path("_", ".", "_", "..", "baz")
     assert replace_path(path, mapper) == expected, "Only replaces mapped parts which are in the special parts tuple"
+
+
+@posix_only
+def test_replace_path_expanduser_posix():
+    with patch.object(os, "environ", {"HOME": "/home/foo"}):
+        assert replace_path("~/bar", lambda s: s) == Path("/home/foo/bar")
+        assert replace_path("foo/bar", lambda s: dict(foo="~").get(s, s)) == Path("~/bar")
+
+
+@windows_only
+def test_replace_path_expanduser_windows():
+    with patch.object(os, "environ", {"USERPROFILE": "C:\\Users\\foo"}):
+        assert replace_path("~\\bar", lambda s: s) == Path("C:\\Users\\foo\\bar")
+        assert replace_path("foo\\bar", lambda s: dict(foo="~").get(s, s)) == Path("~\\bar")
